@@ -1,6 +1,12 @@
-JSDtree_cluster <- function(JSDtree,alpha=0.9)
+JSDtree_cluster <- function(JSDtree,alpha=0.9,draw=T)
 {
 
+
+#cluster JSD matrix on medoids
+clustersMedoid <- pamk(JSDtree)
+clustersMedoidSupport <- pam(JSDtree,clustersMedoid$nc)
+
+if(draw == T){
 #plot heatmap
 heatmap(JSDtree,symm=T)
 
@@ -13,7 +19,8 @@ heatmap(JSDtree,symm=T)
 #cluster JSD matrix on medoids
 clustersMedoid <- pamk(JSDtree)
 clustersMedoidSupport <- pam(JSDtree,clustersMedoid$nc)
-
+}
+else{}
 
 #print clustersMedoid
 res	<- list(clusters=clustersMedoid$nc, cluster_assignments=clustersMedoid[[1]][[3]],cluster_support=clustersMedoidSupport[[7]])
